==> benno-web-2.2.0.tgz: srv/benno/bennoweb/htdocs/ctrl/searchQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */


$queryId = $App->getParam('queryId');

try {
    $StoredQuery = new StoredQuery($queryId);
    $StoredQuery->load();

    $ExtQuery = $StoredQuery->getQuery();

    // show extended Search
    $searchMaskState = $ExtQuery->type;
    $App->setSession('searchMaskState',$searchMaskState);

    // fresh search, thus we start with position 1
    $QueryResult = $Backend->query($ExtQuery,0,$search_limit);
    if ($QueryResult->found == 0) {
        $App->setMsg('MSG_NOTFOUND');
        $sessionMailId = '';
    }
    $sessionMailId = $QueryResult->getSessionMailId(0);

}
catch (Exception $e) {
    if ($e->getMessage() == 'ID_NOT_FOUND') {
        $App->view = 'showList';
    }
    else {
        $App->log($e->getMessage());
        $App->setMsg($e->getMessage());
    }
}

$App->view = 'showList';

?>

==> benno-web-2.2.7.tgz: srv/benno/bennoweb/htdocs/ctrl/searchQuery.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

$queryId = $App->getParam('queryId');

try {
    $StoredQuery = new StoredQuery($queryId);
    $StoredQuery->load();

    $ExtQuery = $StoredQuery->getQuery();

    // show extended Search
    $searchMaskState = $ExtQuery->type;
    $App->setSession('searchMaskState',$searchMaskState);

    // fresh search, thus we start with position 1
    $QueryResult = $Backend->query($archive,$ExtQuery,0,$search_limit);
    if ($QueryResult->found == 0) {
        $App->setMsg('MSG_NOTFOUND');
        $sessionMailId = '';
    }
    $sessionMailId = $QueryResult->getSessionMailId(0);

}
catch (Exception $e) {
    if ($e->getMessage() == 'ID_NOT_FOUND') {
        $App->view = 'showList';
    }
    else {
        $App->log($e->getMessage());
        $App->setMsg($e->getMessage());
    }
}

$App->view = 'showList';

?>
